/**
 ****************************************************************************
 * @file 	H_Hall.c
 * @brief	Motor vector control driver Source File
 * @version	V1.0
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * Copyright(C) Toshiba Electronic Device Solutions Corporation 2019
 *****************************************************************************
 */
#include <stdlib.h>
#include "ipdefine.h"

#define DEFINE_APP
#include "H_Hall.h"
#undef	DEFINE_APP


/*===================================================================*
      Constant Data Definition
 *===================================================================*/
#if (defined(__USE_ENCODER_CH1) && defined(__USE_HALL_CH1))
#define		P_HALL_U		TSB_EN0_INPMON_SPLMONA
#define		P_HALL_V		TSB_EN0_INPMON_SPLMONB
#define		P_HALL_W		TSB_EN0_INPMON_SPLMONZ
#endif /* (__USE_ENCODER_CH1 and __USE_HALL_CH1) */


/*===================================================================*
      Data Definition
 *===================================================================*/
#if defined(__USE_HALL_CH1)
const uint8_t		tHall2idx[] = {0,2,4,3,0,1,5,0};
const uint16_t		tHall2AngCW[] = {ELE_DEG(120),ELE_DEG(180),ELE_DEG(240),ELE_DEG(300),ELE_DEG(0),ELE_DEG(60)};
const uint16_t		tHall2AngCCW[] = {ELE_DEG(180),ELE_DEG(240),ELE_DEG(300),ELE_DEG(0),ELE_DEG(60),ELE_DEG(120)};
#endif /* __USE_HALL_CH1 */


/*===================================================================*
	Proto Type Definition
 *===================================================================*/


#if (defined(__USE_ENCODER_CH1) && defined(__USE_HALL_CH1))
/**
 ********************************************************************************************
 * @brief		Get EleAngle From Hall Sensor.
 *
 * @param[in]	Hall_t* const	_hall	.
 * @param[in]	uint8_t			_rot	.
 *
 * @return		uint16_t	
 ********************************************************************************************
 */
uint16_t	Get_EleAngleFromHall(Hall_t* const _hall, uint8_t _rot)
{
	uint16_t	angle;
	if (_rot == cCW)
	{
		angle = tHall2AngCW[_hall->ModeIdx] + ELE_DEG(60);
	}
	else {
	    angle = tHall2AngCCW[_hall->ModeIdx] - ELE_DEG(60);
	}

	return(angle);
}


/**
 ********************************************************************************************
 * @brief		Init HallCon.
 *
 * @return		none
 ********************************************************************************************
 */

void	init_HallCon(Hall_t* const _hall)
{
	/* init port */
	TSB_PD->IE |= BIT8(0, 0, 0, 0, 0, 1, 1, 1); 		/* */

	/* init ram */
	/* CH1 */
	_hall->ModeIdx = _hall->ModeIdx1 = 0xff;
	
}


/**
 ********************************************************************************************
 * @brief		H_Hall.
 *
 * @param[in]	hall_t* const	_hall	.
 *
 * @return		none
 ********************************************************************************************
 */
void	H_HallCon(Hall_t* const _hall)
{
	int		hu,hv,hw;
	int		portbuf;

	/***** hall sensor port chataring *****/
	hu = P_HALL_U;
	hv = P_HALL_V;
	hw = P_HALL_W;
	portbuf = ((hw<<2)|(hv<<1)|(hu));

	_hall->SensorPos = portbuf;

	/***** Sensor position to idx. *****/
	_hall->ModeIdx = tHall2idx[_hall->SensorPos];


	/***** theta cal *****/
	if(_hall->SensorPos != 0)						/* get sonsor port? */
	{
		if(_hall->ModeIdx != _hall->ModeIdx1)		/* change hall sensor data? */
		{

          if(_hall->ModeIdx1 != 0xff){				/* Get previous sensor data? */

				/***** Detect rotation by hall sensor. *****/
				if(_hall->ModeIdx == 0)
				{
					if(_hall->ModeIdx1 == 5)
					{
						_hall->rot = cCW;
					}
					else
					{
						_hall->rot = cCCW;
					}
				}
				else if(_hall->ModeIdx == 5)
				{
					if(_hall->ModeIdx1 == 0)
					{
						_hall->rot = cCCW;
					}
					else
					{
						_hall->rot = cCW;
					}
				}
				else
				{
					if(_hall->ModeIdx > _hall->ModeIdx1)
					{
						_hall->rot = cCW;
					}
					else{
						_hall->rot = cCCW;
					}
				}

				/***** Set Electrical angle *****/
				if ( _hall->rot == cCW) {
					// CW //
					_hall->theta_hall = tHall2AngCW[_hall->ModeIdx];
				}
				else{
					// CCW //
					_hall->theta_hall = tHall2AngCCW[_hall->ModeIdx];
				}

				/***** Set electrical angle correction timing. *****/
				if(_hall->SensorFlg.hall_detect == CLEAR)			/* first detection? (from after reset.) */
				{
					_hall->SensorFlg.hall_detect = SET;
					_hall->SensorFlg.ele_correct = SET;
				}
				else{
					if(_hall->ModeIdx == 0)			/* 360 degree intervals */
					{
						_hall->SensorFlg.ele_correct = SET;
					}
				}

			}
			_hall->ModeIdx1 = _hall->ModeIdx;		/* Save previous sensor data. */
		}
	}
}
#endif /* (__USE_ENCODER_CH1 and __USE_HALL_CH1) */

